@@ -15,14 +15,17 @@ import re
 import time
 import logging
 import threading
-from queue import Queue
-from queue import Empty
+try:
+    from queue import Queue
+    from queue import Empty
+except ImportError:
+    from Queue import Queue
+    from Queue import Empty
 
 from zenutils import serviceutils
 from zenutils import errorutils
 from zenutils import hashutils
 
-
 _logger = logging.getLogger(__name__)
 
 NONE = "NONE"
@@ -120,7 +123,7 @@ class ZenCacheService(serviceutils.ServiceBase):
             raise errorutils.UserPasswordError()
         configed_password = users[username]
         if hashutils.validate_password_hash(password, configed_password):
-            _protocol_instance.authenticated = True
+            _protocol_instance.authenticated = True # set connection to authenticated
             return True
         else:
             return False
